@@ -265,6 +265,12 @@ EOT
             exit 1
         fi
         rm -f .mkcert.cfg
+        prompt="8. Certificate Validity     (days)          [365]:"
+        echo dummy | awk '{ printf("%s", prompt); }' "prompt=$prompt"
+        read days
+        if [ ".$days" = . ]; then
+            days=365
+        fi
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 3: Generating X.509 certificate signed by Snake Oil CA [server.crt]${T_ME}"
@@ -286,7 +292,7 @@ EOT
         fi
         if [ ".$algo" = .RSA ]; then
             $openssl x509 $extfile \
-                          -days 365 \
+                          -days $days \
                           -CAserial .mkcert.serial \
                           -CA $sslcrtdir/snakeoil-ca-rsa.crt \
                           -CAkey $sslkeydir/snakeoil-ca-rsa.key \
@@ -294,7 +300,7 @@ EOT
                           -out $sslcrtdir/server.crt
         else
             $openssl x509 $extfile \
-                          -days 365 \
+                          -days $days \
                           -CAserial .mkcert.serial \
                           -CA $sslcrtdir/snakeoil-ca-dsa.crt \
                           -CAkey $sslkeydir/snakeoil-ca-dsa.key \
@@ -497,6 +503,12 @@ EOT
             exit 1
         fi
         rm -f .mkcert.cfg
+        prompt="8. Certificate Validity     (days)          [365]:"
+        echo dummy | awk '{ printf("%s", prompt); }' "prompt=$prompt"
+        read days
+        if [ ".$days" = . ]; then
+            days=365
+        fi
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 3: Generating X.509 certificate for CA signed by itself [ca.crt]${T_ME}"
@@ -515,7 +527,7 @@ nsCertType       = sslCA
 EOT
         fi
         $openssl x509 $extfile \
-                      -days 365 \
+                      -days $days \
                       -signkey $sslkeydir/ca.key \
                       -in      $sslcsrdir/ca.csr -req \
                       -out     $sslcrtdir/ca.crt
@@ -605,6 +617,12 @@ EOT
             exit 1
         fi
         rm -f .mkcert.cfg
+        prompt="8. Certificate Validity     (days)          [365]:"
+        echo dummy | awk '{ printf("%s", prompt); }' "prompt=$prompt"
+        read days
+        if [ ".$days" = . ]; then
+            days=365
+        fi
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 6: Generating X.509 certificate signed by own CA [server.crt]${T_ME}"
@@ -625,7 +643,7 @@ EOT
             echo '01' >.mkcert.serial
         fi
         $openssl x509 $extfile \
-                      -days 365 \
+                      -days $days \
                       -CAserial .mkcert.serial \
                       -CA    $sslcrtdir/ca.crt \
                       -CAkey $sslkeydir/ca.key \
